# Changelog — free/essentials/deployment

## 0.1.10 — Automated patch release triggered by content hash change (2026-02-14)

- chore: Automated patch release triggered by content hash change

## 0.1.9 — Automated patch release triggered by content hash change (2026-02-14)

- chore: Automated patch release triggered by content hash change

## 0.1.8 — Automated patch release triggered by content hash change (2026-02-14)

- chore: Automated patch release triggered by content hash change

## 0.1.7 — Automated patch release triggered by content hash change (2026-02-14)

- chore: Automated patch release triggered by content hash change

## 0.1.6 — Automated patch release triggered by content hash change (2026-02-14)

- chore: Automated patch release triggered by content hash change

## 0.1.5 — Automated patch release triggered by content hash change (2026-02-14)

- chore: Automated patch release triggered by content hash change

## 0.1.4 — Automated patch release triggered by content hash change (2026-02-11)

- chore: Automated patch release triggered by content hash change

## 0.1.3 — Runtime alignment (2025-12-06)

- Standardized the default Python runtime to 3.10 and Node runtime to 18 across deployment templates
  and options so downstream projects match the global platform baseline.

## 0.1.0 — Initial baseline (2025-12-04)

- Initial public baseline.
